/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013
//***********************************************************************************************************

#include <stdio.h>
#include "N78E366A.h"
#include "Typedef.h"
#include "Common.h"

#define   ERASE_ALL_LD        0x62
#define   FLASH_READ_LD       0x40
#define   BYTE_PROGRAM_LD     0x61
/*-----------------The ISP test Result----------------------------------------------------------------------
          Test OK   P2 = 0xCC
          Test Fail P2 = 0x78
----------------------------------------------------------------------------------------------------------*/
void ISP_Error(void)
{
    P2 = 0x78;
    while(1);
}
//-----------------------------------------------------------------------------------------------------------
void Enable_ISP_Mode(void)
{   
    bit EA_tmp;

    /* Enable ISP and LUDE */ 
    EA_tmp = EA;
    EA = 0;
    TA = 0xAA;
    TA = 0x55;
    CHPCON |= 0x21; 
    EA = EA_tmp;
}
//-----------------------------------------------------------------------------------------------------------
void Disable_ISP_Mode(void)
{   
    bit EA_tmp;

    /* Disable ISP */ 
    EA_tmp = EA;
    EA = 0;
    TA = 0xAA;
    TA = 0x55;
    CHPCON &= 0xFE;     
    EA = EA_tmp; 
}
//-----------------------------------------------------------------------------------------------------------
void Trigger_ISP(void)
{     
    bit EA_tmp;
  
    EA_tmp = EA;
    EA = 0;
    TA = 0xAA;
    TA = 0x55;
    ISPTRG |= 0x01; 
    EA = EA_tmp;             
}
//-----------------------------------------------------------------------------------------------------------
void Erase_LD(void)
{   
    UINT8 u8Count;

    Enable_ISP_Mode();
    P2 = 0x01;

    ISPAL = 0;
    ISPCN = ERASE_ALL_LD;
    ISPCN = 0x62;
    
    for(u8Count = 0; u8Count <= 9; u8Count++)           //LD has 10 pages (256 byte/page) 
    {        
        ISPAH = u8Count;    
        Trigger_ISP();
    } 

    Disable_ISP_Mode();
}
//-----------------------------------------------------------------------------------------------------------
void Erase_LD_Verify(void)
{   
    UINT16 u16Count;

    Enable_ISP_Mode();
    P2 = 0x02;

    ISPAL = 0;
    ISPAH = 0;
    ISPCN = FLASH_READ_LD;

    for(u16Count = 0; u16Count <= 0x09FF; u16Count++)   //LD addressed from 000h~9FFh
    {    
        ISPFD = 0;    
        Trigger_ISP();

        if(ISPFD != 0xFF)
            ISP_Error();
        
        ISPAL++;
        if(ISPAL == 0)
            ISPAH++;
    } 
    
    Disable_ISP_Mode();
}
//-----------------------------------------------------------------------------------------------------------
void Program_LD(void)
{   
    UINT16 u16Count;

    Enable_ISP_Mode();
    P2 = 0x03;

    ISPAL = 0;
    ISPAH = 0;
    ISPFD = 0xFF;
    ISPCN = BYTE_PROGRAM_LD;

    for(u16Count = 0;u16Count <= 0x09FF; u16Count++)
    {    
        ISPFD++;     
        Trigger_ISP();
        
        ISPAL++;
        if(ISPAL == 0)
            ISPAH++;
    } 

    Disable_ISP_Mode();
}
//-----------------------------------------------------------------------------------------------------------
void Program_LD_Verify(void)
{   
    UINT16 u16Count;
    UINT8  u8Read_Data;

    Enable_ISP_Mode();
    P2 = 0x04;

    ISPAL = 0;
    ISPAH = 0;
    u8Read_Data = 0x00;
    ISPCN = FLASH_READ_LD;

    for(u16Count = 0;u16Count <= 0x09FF; u16Count++)
    {    
        Trigger_ISP();
        if(ISPFD != u8Read_Data)
            ISP_Error();

        ISPAL++;
        if(ISPAL == 0)
            ISPAH++;
        u8Read_Data++;
    } 
    
    Disable_ISP_Mode();
}
//-----------------------------------------------------------------------------------------------------------
void main (void) 
{
    InitialUART0_Timer1(9600);           /* 9600 Baud Rate @ 11.0592MHz */

    printf ("\n*===================================================================  ");
    printf ("\n*  Name: N78E366A ISP APROM Program LDROM Sample Code.                ");
    printf ("\n*===================================================================\n");

    Erase_LD();
    Erase_LD_Verify();
    Program_LD();
    Program_LD_Verify();

    printf ("\n   Finished ISP APROM Program LDROM!!!\n");
    P2 = 0xCC;
    while(1);
}
//-----------------------------------------------------------------------------------------------------------
