/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013
//***********************************************************************************************************
//  1: send 0x90,0x01,0x02,0x03 to Slave
//  2: Receive 0xAA,0x55 from Slave
//  3: If test ok, P0 can show 0x55,P2 can show 0x55, P12 and P13 can toggle
//***********************************************************************************************************
#include <stdio.h>
#include <intrins.h>
#include <string.h>
#include "N78E366A.h"
#include "Typedef.h"
#include "Define.h"
#include "Common.h"
#include "Delay.h"

#define set_SSOE        SPCR |= SET_BIT7
#define set_SPE         SPCR |= SET_BIT6
#define set_LSBFE       SPCR |= SET_BIT5
#define set_MSTR        SPCR |= SET_BIT4
#define set_CPOL        SPCR |= SET_BIT3
#define set_CPHA        SPCR |= SET_BIT2
#define set_SPR1        SPCR |= SET_BIT1
#define set_SPR0        SPCR |= SET_BIT0

#define set_DRSS        SPSR |= SET_BIT3
#define set_ESPI        EIE  |= SET_BIT0

#define clr_SSOE        SPCR &= CLR_BIT7
#define clr_SPE         SPCR &= CLR_BIT6
#define clr_LSBFE       SPCR &= CLR_BIT5
#define clr_MSTR        SPCR &= CLR_BIT4
#define clr_CPOL        SPCR &= CLR_BIT3
#define clr_CPHA        SPCR &= CLR_BIT2
#define clr_SPR1        SPCR &= CLR_BIT1
#define clr_SPR0        SPCR &= CLR_BIT0

#define clr_DRSS        SPSR &= CLR_BIT3
#define clr_SPIF        SPSR &= CLR_BIT7

#define SS_PIN          P14
//-----------------------------------------------------------------------------------------------------------
void SPI_Interrupt_ISR(void) interrupt 8
{
    clr_SPIF; 
}
//-----------------------------------------------------------------------------------------------------------
void SPI_Error(void)
{
    P2 = 0x78;
    while(1);
}
//-----------------------------------------------------------------------------------------------------------
void SPI_Initial(void)
{
    /* Enable Port 0 to weakly pull-up */
    P0OR |= SET_BIT0;

    /* SPI clock = Fosc/128 */
    set_SPR0;
    set_SPR1;

    /* /SS General purpose I/O ( No Mode Fault ) */
    set_DRSS;
    clr_SSOE;

    /* SPI in Master mode */
    set_MSTR;

    /* MSB first */
    clr_LSBFE;

    clr_CPOL;
    set_CPHA;
    
    /* Enable SPI function */
    set_SPE;     
}
//-----------------------------------------------------------------------------------------------------------
void Start_Test_SPI(UINT8 *pu8MID,UINT8 *pu8DID)
{
    SS_PIN = 0;
    clr_SPIF;

    SPDR = 0x90;                   /* Send 0x90 to Slave */
    while((SPSR&0x80) == 0x00);
    clr_SPIF;

    SPDR = 0x01;                   /* Send 0x01 to Slave */
    while((SPSR&0x80) == 0x00);
    clr_SPIF;           
                                       
    SPDR = 0x02;                   /* Send 0x02 to Slave */
    while((SPSR&0x80) == 0x00);    
    clr_SPIF;

     SPDR = 0x03;                  /* Send 0x03 to Slave */
    while((SPSR&0x80) == 0x00);
    clr_SPIF;           

    SPDR = 0xFF;                   
    while((SPSR&0x80) == 0x00);
    clr_SPIF;
    *pu8MID = SPDR;                /* Receive Slave 1st DATA from Slave */       
            
    SPDR = 0xFF;                   
    while((SPSR&0x80) == 0x00); 
    clr_SPIF;           
    *pu8DID = SPDR;                /* Receive Slave 2nd DATA from Slave */
    
    SS_PIN = 1;    
}
//-----------------------------------------------------------------------------------------------------------
void main(void)
{      
    UINT8 u8MID,u8DID;
    
    Delay1ms(200);                  /* Waiting the Slave ready */
    P2 = 0x22;
    SPI_Initial();

    Start_Test_SPI(&u8MID,&u8DID);

    P0 = u8MID;
    P2 = u8DID;

    if((u8MID != 0xAA)&&(u8DID != 0x55))
        SPI_Error();

    while(1)                         /* Test ok then P12 flash */
    {
        P12 = 0;
        Delay1ms(300);
        P12 = 1;
        Delay1ms(300);
    }
}
//-----------------------------------------------------------------------------------------------------------
