/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013
//***********************************************************************************************************

#include "Timer01.h"
#if DEMO == 3


/*===========================================================================================================
 * Before using this demo code, please set DEMO in "TImer01.h" to decide which *.c is used for different 
 * timer modes.
 *
 * This file set up Timer 0 in mode 3 (dual 8-bit) and Timer 1 in different modes. The clock gating, timer
 * /counter mode are all configured by configuration wizard. P1.0 and P1.1 toggles each Timer 0 and Timer 1 
 * interrupt respectively. For Timer 1 has no interrupt, its counter value shows on P2 and P0. 
 *===========================================================================================================

/*
//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
//
// <o0.2> Timer/Counter 0 Select
//     <0=> Timer                       <1=> Counter
// <o0.6> Timer/Counter 1 Select
//     <0=> Timer                       <1=> Counter
// <o0.0..1> Timer 0 Mode Select
//     <3=> (3) dual 8-bit mode
// <o0.4..5> Timer 1 Mode Select
//     <0=> (0) 13-bit mode    	    	<1=> (1) 16-bit mode
//     <2=> (2) 8-bit auto-reload mode  <3=> (3) halt
// <q0.3> Timer 0 Clock Hardware Gating
// <q0.7> Timer 1 Clock Hardware Gating
//
//-------- <<< end of configuration section >>> ------------------------------
*/

#include "N78E366A.H"

#define TIMER_MODE      0x9B
#define TH0_INIT        0x00
#define TL0_INIT        0x00
#define TH1_INIT        0x00
#define TL1_INIT        0x00

/************************************************************************************************************
*    TIMER 0 interrupt subroutine
************************************************************************************************************/
void Timer0_ISR (void) interrupt 1  //interrupt address is 0x000B
{              
    TL0 = TL0_INIT;                 //reload by software    
    P10 = ~P10;                     //P1.0 toggle when interrupt
}

/************************************************************************************************************
*    TIMER 1 interrupt subroutine
************************************************************************************************************/
void Timer1_ISR (void) interrupt 3  //interrupt address is 0x001B
{           
    TH0 = TH0_INIT;
    P11 = ~P11;                     //P1.1 toggle when interrupt
}

/************************************************************************************************************
*    Main function 
************************************************************************************************************/
void main (void)
{
    TMOD = TIMER_MODE;              //Timer 0 and Timer 1 mode configuration
    
    TH0 = TH0_INIT;                 //initial counter values 
    TL0 = TL0_INIT;    
    TH1 = TH1_INIT;
    TL1 = TL1_INIT;    
    
    ET0 = 1;                        //enable TL0 counter interrupt
    ET1 = 1;                        //enable TH0 counter interrupt
    EA = 1;                         //enable interrupts
    TR0 = 1;                        //TL0 run
    TR1 = 1;                        //TH0 run
    while(1)
    {
        P2 = TH1;                   //for Timer 1 has no interrupt while Timer 0 in mode 3, show on ports
        P0 = TL1;
    }
}

#endif
